@@ -9,7 +9,7 @@
 **  This is part of the CTSim program
 **  Copyright (c) 1983-2001 Kevin Rosenberg
 **
-**  $Id: timer.h 10680 2005-08-31 04:27:46Z kevin $
+**  $Id: timer.h 11602 2007-04-01 14:33:58Z kevin $
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License (version 2) as
@@ -30,7 +30,7 @@
 
 // pragma line required for Fedora 4 and wxWin 2.4.2 
 #if defined(__GNUG__) && !defined(__APPLE__)
-    #pragma interface "timer.h"
+   #pragma implementation "timer.h"
 #endif
 
 #ifdef HAVE_CONFIG_H
